<?xml version="1.0" encoding="UTF-8"?>
<!--
/**
* XSLT TEI to Json : index for MiniSearch
* @author AnneGF@CNRS
* @date : 2024
* TODO : all books
* XML : Livre I.xml (à terme à changer donc...)
* Output : templates/search.html.j2

*/
-->

<!DOCTYPE xsl [
    <!ENTITY times "&#215;">
    <!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:tei="http://www.tei-c.org/ns/1.0"
    xmlns="http://www.w3.org/1999/xhtml" exclude-result-prefixes="xs tei" version="2.0">

    <xsl:output method="html" indent="yes" encoding="UTF-8" omit-xml-declaration="yes"/>

    <xsl:variable name="br">
        <xsl:text>
</xsl:text>
    </xsl:variable>

    <xsl:template match="/">
        <xsl:variable name="all_witness_id" select="distinct-values(//@wit/tokenize(., ' '))"/>
        <xsl:text>{% extends "base.html.j2" %}</xsl:text>
        <xsl:value-of select="$br"/>
        <xsl:text>{% block css %}</xsl:text>
        <link href="/static/css/app_minisearch.css" rel="stylesheet"/>
        <xsl:text>{% endblock %}</xsl:text>
        <xsl:value-of select="$br"/>
        <xsl:text>{% block containertype %}container{% endblock %}</xsl:text>
        <xsl:value-of select="$br"/>
        <xsl:text>{% block pageTitle %}Recherche{% endblock %}</xsl:text>
        <xsl:value-of select="$br"/>
        <xsl:text>{% block body %}</xsl:text>
        <xsl:value-of select="$br"/>

        <h1>Chercher dans un vers...</h1>
        <div id="app">
            <div class="App">
                <div class="Loader">chargement des données...</div>
                <div class="SearchBox">
                    <div class="Search">
                        <input type="text"/>
                        <button class="clear">×</button>
                    </div>
                    <ul class="SuggestionList"/>
                    <details class="AdvancedOptions" open="">
                        <summary>Options avancées</summary>
                        <form class="options">
                            <div>
                                <b>Chercher dans les manuscrits&nbsp;:</b>
                                <label>
                                    <b><input type="checkbox" name="fields" value="lem" checked=""
                                        />&nbsp;BnFfr 2817</b>
                                </label>
                                <xsl:for-each select="$all_witness_id">
                                    <xsl:variable name="wit" select="replace(., '#', '')"/>
                                    <label><input type="checkbox" name="fields" value="{$wit}"
                                            checked=""/>&nbsp;<xsl:value-of select="$wit"/></label>
                                    <xsl:text> </xsl:text>
                                </xsl:for-each>
                            </div>
                            <div>
                                <b>Élargir la recherche&nbsp;:</b>
                                <br/>
                                <label><input type="checkbox" name="prefix" value="true" checked=""
                                    /> Rechercher les mots qui commencent par... (par exemple
                                        <code>qui</code> renverra <code>qui</code>,
                                        <code>quidem</code>, etc.)</label>
                                <br/>
                                <label><input type="checkbox" name="fuzzy" value="true" checked=""/>
                                    Autoriser les résultats approximatifs</label>
                            </div>
                            <div>
                                <b>Rechercher </b>
                                <label><input type="radio" name="combineWith" value="OR" checked=""
                                    /> au moins un des termes (<code>roy</code> ou
                                    <code>ost</code>)</label>
                                <label><input type="radio" name="combineWith" value="AND"/> tous les
                                    termes (<code>roy</code> et <code>ost</code>)</label>
                            </div>
                        </form>
                    </details>
                </div>
                <div class="m-4">
                    <p class="Explanation">Votre recherche n'a donné aucun résultat. Vous pouvez
                        élargir votre recherche en cherchant <i>les mots commençant par</i> et/ou en
                        autorisant les <i>résultats approximatifs</i>.</p>
                </div>
                <ul class="resultsList"/>
            </div>
        </div>

        <script src="https://cdn.jsdelivr.net/npm/minisearch@7.1.0/dist/umd/index.min.js"/>
        <script src="/static/js/auto_app_minisearch.js"/>
        <script src="/static/js/app_minisearch.js"/>
        <xsl:value-of select="$br"/>
        <xsl:text>{% endblock %}</xsl:text>
    </xsl:template>

</xsl:stylesheet>
